@@ -11,7 +11,7 @@ from django.utils.translation import ugettext as _
 
 from xauth.forms import AccountForm
 from xauth.models import XauthAssociation
-from xauth.util import import_path
+from xauth.util import import_path, get_redirect_url
 
 logger = logging.getLogger('xauth.views')
 
@@ -24,12 +24,6 @@ def clear_xauth_session(request):
         pass
 
 
-def get_redirect_url(request, default_url):
-    "Extract saved redirect url or use default."
-
-    return request.session.get('xauth_redirect_url') or default_url
-
-
 def xauth_login(request):
     "Display initial Log In page."
 
